FindChatConversationsResult class

Respuesta de GET /conversations: las conversaciones del visitante del token, actividad más reciente primero.

Constructors

FindChatConversationsResult({required String visitorId, required int total, required List<FindChatConversationSummary> conversations})
const
FindChatConversationsResult.fromJson(Map<String, dynamic> json)
factory

Properties

conversations List<FindChatConversationSummary>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final
visitorId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited