FindChatDrawerView class
Modo FindChatMode.drawer: sin burbuja — se abre/cierra solo por código
(controller.open()/close()/toggle()). En pantallas angostas (<600dp)
se muestra como bottom sheet; en pantallas anchas, como panel lateral
deslizándose desde la derecha. Se inserta vía Overlay, igual que
FindChatFloatingBubble — requiere un Navigator/Overlay ancestro.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FindChatDrawerView
Constructors
- FindChatDrawerView({Key? key, required FindChatController controller, required bool dark, required bool gptStyle, FindChatThemeBuilder? themeBuilder, bool showHeader = true, Color? userBubbleColor, Color? assistantBubbleColor, Color? userBubbleTextColor, Color? assistantBubbleTextColor, double? inputHeight, FindChatActionsBuilder? actionsBuilder})
-
const
Properties
- actionsBuilder → FindChatActionsBuilder?
-
final
- assistantBubbleColor → Color?
-
final
- assistantBubbleTextColor → Color?
-
final
- controller → FindChatController
-
final
- dark → bool
-
final
- gptStyle → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputHeight → double?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHeader → bool
-
final
- themeBuilder → FindChatThemeBuilder?
-
final
- userBubbleColor → Color?
-
final
- userBubbleTextColor → Color?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FindChatDrawerView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited